<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="pt">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy da aplicação</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Marcar &quot;Usar um proxy&quot; no menu de contexto da aplicação no lançador depois de configurado</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Porta inválida</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>A ligar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Tem a certeza que deseja eliminar esta configuração?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Ligação por cabo %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Ligação sem fios %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Ligação PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nova VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy da aplicação</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot pessoal</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da rede</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rede por cabo</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rede sem fios</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avião</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de rede por cabo</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adicionar ligação de rede</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador de rede sem fios</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Ligar a uma rede oculta</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Criar ligação PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Estado da VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Criar VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuração URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Criar Ponto de Acesso</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ponto de Acesso</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Principal</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de Rede</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidade</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avião</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Endereço DNS inválido</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Não Vincula</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Endereço MAC do dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Endereço MAC Clonado</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>O nome de já existe</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Ligação automática</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Ponto de Acesso</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Adicionar Definições</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Criar Ponto de Acesso</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço IP duplicado</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP inválido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de rede inválida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Apenas um Gateway é permitido</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ponto de acesso inválido</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Endereço IP duplicado</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço IP inválido</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Apenas um Gateway é permitido</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ponto de acesso inválido</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Apenas aplicado aos recursos correspondentes</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de rede</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefixo</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Endereço de IP inválido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de rede inválida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Ponto de acesso inválido</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da rede</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy da aplicação</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo de avião</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detalhes da rede</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflito de IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurar com Gestor de Redes</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot pessoal</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Serviço</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar Autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sem compressão de dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sem Compressão de Dados Deflacionados</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sem Compressão de Cabeçalho TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sem compressão de campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sem Compressão de Endereço / Controlo</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar pacotes de eco PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utilizar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128 bits</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Com estado</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Criar Ligação PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy do sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorar as configurações de proxy para os hosts e domínios acima</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuração URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS Tunelado</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP Protegido</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Guardar palavra-passe para este utilizador</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Guardar palavra-passe para todos os utilizadores</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Perguntar sempre</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anónimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versão 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versão 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticação EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidade</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de palavra-passe</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado do utilizador</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anónimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Aprovisionamento</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Ficheiro PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticação interna</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versão PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Palavra-passe privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Palavra-passe inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Pessoal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Segurança Requerida</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Palavra-passe inválida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Pessoal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Infraestrutura</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Chave partilhada</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Abrir sistema</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticação</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avançada</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalizar porta de Gateway</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Porta de Gateway</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalizar intervalo de renegociação</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo de renegociação</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utilizar compressão de dados LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Utilizar ligação TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Utilizar dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalizar túnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizar tamanho de fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamanho de fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringir túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Aleatorizar hosts remotos</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avançada</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (predefinição)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Segura (predefinição)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Fraca</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Quando disponível (predefinição)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Sempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupo 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupo 2 (predefinição)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupo 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (predefinição)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupo 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domínio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Encriptação</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo NAT transversal</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Sigilo encaminhado</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Porta Local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Desativar deteção de pares mortos</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>IPsec VPN</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Ativar IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome de grupo</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID do grupo</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave pré-partilhada </translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmos Fase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmos fase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir o Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado do utilizador</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Utilizar FSDI para a palavra-passe da chave</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválida</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados com palavra-passe (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chave estática</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticação</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado do utilizador</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de palavra-passe</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Palavra-passe privada</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar direção da chave</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direção da chave</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Remoto</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Local</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>PPP VPN</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tudo disponível (predefinição)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos seguro)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (mais seguro)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Recusar autenticação EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Recusar autenticação PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Recusar autenticação CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Recusar Autenticação MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Recusar autenticação MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sem compressão de dados BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sem Compressão de Dados Deflacionados</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sem Compressão de Cabeçalho TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sem compressão de campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sem Compressão de Endereço / Controlo</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar pacotes de eco PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utilizar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Com estado</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Estado da VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Criar VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Erro ao importar</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erro no ficheiro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Requerido</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do Servidor</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Repetir indefinidamente quando falhar</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Ficheiro CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorar avisos de certificado</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Utilize extensões de hostname TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Segurança da VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinição</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticação HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de palavra-passe</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domínio NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP do Servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválida</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chave privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Cartão inteligente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chave pré-partilhada </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticação</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado do utilizador</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar um endereço de IP interno</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Impor encapsulamento UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Utilizar compressão de IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Ativar propostas de cifra personalizadas</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticação TLS VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinição</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Correspondência de assunto</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de certificado remoto</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Ficheiro chave</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar direção da chave</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Direção da chave</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway inválida</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Perguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Não Requerido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opções de palavra-passe</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Palavra-passe</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome de grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Palavra-passe do grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Utilizar autenticação híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Ficheiro CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Ligue primeiro o cabo de rede</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptador de rede por cabo</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Adicionar ligação de rede</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Selecionar definições</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptador de rede sem fios</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Fechar hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desativar primeiro o hotspot se pretende ligar a uma rede sem fios</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Ligar a uma rede oculta</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Não Vincula</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Endereço MAC do dispositivo</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>